==> struts2-jquery-plugin-3.7.0-sources.jar: com/jgeppert/struts2/jquery/views/velocity/components/SelectDirective.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.views.velocity.components;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts2.components.Component;

import com.jgeppert.struts2.jquery.components.Select;
import com.opensymphony.xwork2.util.ValueStack;

/**
 * 
 * @see Select
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 * 
 */
public class SelectDirective extends JqueryAbstractDirective {
  public String getBeanName()
  {
    return "select";
  }

  protected Component getBean(ValueStack stack, HttpServletRequest req, HttpServletResponse res)
  {
    return new Select(stack, req, res);
  }

  public int getType()
  {
    return BLOCK;
  }
}

==> struts2-jquery-plugin-4.0.2-sources.jar: com/jgeppert/struts2/jquery/views/velocity/components/SelectDirective.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.views.velocity.components;

import com.jgeppert.struts2.jquery.components.Select;
import com.opensymphony.xwork2.util.ValueStack;
import org.apache.struts2.components.Component;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 * @see Select
 */
public class SelectDirective extends JqueryAbstractDirective {
    public String getBeanName() {
        return "select";
    }

    protected Component getBean(ValueStack stack, HttpServletRequest req, HttpServletResponse res) {
        return new Select(stack, req, res);
    }

    public int getType() {
        return BLOCK;
    }
}
